summaryrefslogtreecommitdiffstats
path: root/kaddressbook/kcmconfigs
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /kaddressbook/kcmconfigs
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kaddressbook/kcmconfigs')
-rw-r--r--kaddressbook/kcmconfigs/addhostdialog.cpp18
-rw-r--r--kaddressbook/kcmconfigs/addhostdialog.h4
-rw-r--r--kaddressbook/kcmconfigs/addresseewidget.cpp68
-rw-r--r--kaddressbook/kcmconfigs/addresseewidget.h24
-rw-r--r--kaddressbook/kcmconfigs/extensionconfigdialog.cpp8
-rw-r--r--kaddressbook/kcmconfigs/extensionconfigdialog.h2
-rw-r--r--kaddressbook/kcmconfigs/kabconfigwidget.cpp102
-rw-r--r--kaddressbook/kcmconfigs/kabconfigwidget.h22
-rw-r--r--kaddressbook/kcmconfigs/kcmkabconfig.cpp10
-rw-r--r--kaddressbook/kcmconfigs/kcmkabconfig.h2
-rw-r--r--kaddressbook/kcmconfigs/kcmkabcustomfields.cpp22
-rw-r--r--kaddressbook/kcmconfigs/kcmkabcustomfields.h14
-rw-r--r--kaddressbook/kcmconfigs/kcmkabldapconfig.cpp14
-rw-r--r--kaddressbook/kcmconfigs/kcmkabldapconfig.h4
-rw-r--r--kaddressbook/kcmconfigs/ldapoptionswidget.cpp80
-rw-r--r--kaddressbook/kcmconfigs/ldapoptionswidget.h18
16 files changed, 206 insertions, 206 deletions
diff --git a/kaddressbook/kcmconfigs/addhostdialog.cpp b/kaddressbook/kcmconfigs/addhostdialog.cpp
index b3eb60bc..14abca14 100644
--- a/kaddressbook/kcmconfigs/addhostdialog.cpp
+++ b/kaddressbook/kcmconfigs/addhostdialog.cpp
@@ -21,11 +21,11 @@
without including the source code for Qt in the source distribution.
*/
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qspinbox.h>
-#include <qtooltip.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
+#include <tqspinbox.h>
+#include <tqtooltip.h>
#include <kaccelmanager.h>
#include <kbuttonbox.h>
@@ -33,13 +33,13 @@
#include <klocale.h>
#include "addhostdialog.h"
-AddHostDialog::AddHostDialog( KPIM::LdapServer *server, QWidget* parent, const char* name )
+AddHostDialog::AddHostDialog( KPIM::LdapServer *server, TQWidget* parent, const char* name )
: KDialogBase( Plain, i18n( "Add Host" ), Ok | Cancel, Ok, parent, name, true, true )
{
mServer = server;
- QWidget *page = plainPage();
- QHBoxLayout *layout = new QHBoxLayout( page, marginHint(), spacingHint() );
+ TQWidget *page = plainPage();
+ TQHBoxLayout *layout = new TQHBoxLayout( page, marginHint(), spacingHint() );
mCfg = new KABC::LdapConfigWidget(
KABC::LdapConfigWidget::W_USER |
@@ -98,7 +98,7 @@ AddHostDialog::~AddHostDialog()
{
}
-void AddHostDialog::slotHostEditChanged( const QString &text )
+void AddHostDialog::slotHostEditChanged( const TQString &text )
{
enableButtonOK( !text.isEmpty() );
}
diff --git a/kaddressbook/kcmconfigs/addhostdialog.h b/kaddressbook/kcmconfigs/addhostdialog.h
index 84f5a0c9..12d145f0 100644
--- a/kaddressbook/kcmconfigs/addhostdialog.h
+++ b/kaddressbook/kcmconfigs/addhostdialog.h
@@ -37,14 +37,14 @@ class AddHostDialog : public KDialogBase
Q_OBJECT
public:
- AddHostDialog( KPIM::LdapServer* server, QWidget* parent = 0, const char* name = 0 );
+ AddHostDialog( KPIM::LdapServer* server, TQWidget* parent = 0, const char* name = 0 );
~AddHostDialog();
signals:
void changed( bool );
private slots:
- void slotHostEditChanged( const QString& );
+ void slotHostEditChanged( const TQString& );
virtual void slotOk();
private:
KABC::LdapConfigWidget *mCfg;
diff --git a/kaddressbook/kcmconfigs/addresseewidget.cpp b/kaddressbook/kcmconfigs/addresseewidget.cpp
index 610b94b8..1c074d39 100644
--- a/kaddressbook/kcmconfigs/addresseewidget.cpp
+++ b/kaddressbook/kcmconfigs/addresseewidget.cpp
@@ -21,12 +21,12 @@
without including the source code for Qt in the source distribution.
*/
-#include <qcstring.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlistbox.h>
-#include <qpushbutton.h>
+#include <tqcstring.h>
+#include <tqgroupbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlistbox.h>
+#include <tqpushbutton.h>
#include <dcopclient.h>
@@ -40,26 +40,26 @@
#include "addresseewidget.h"
-NamePartWidget::NamePartWidget( const QString &title, const QString &label,
- QWidget *parent, const char *name )
- : QWidget( parent, name ), mTitle( title ), mLabel( label )
+NamePartWidget::NamePartWidget( const TQString &title, const TQString &label,
+ TQWidget *parent, const char *name )
+ : TQWidget( parent, name ), mTitle( title ), mLabel( label )
{
- QHBoxLayout *layout = new QHBoxLayout( this );
+ TQHBoxLayout *layout = new TQHBoxLayout( this );
- QGroupBox *group = new QGroupBox( 0, Qt::Vertical, title, this );
- QGridLayout *groupLayout = new QGridLayout( group->layout(), 2, 2,
+ TQGroupBox *group = new TQGroupBox( 0, Qt::Vertical, title, this );
+ TQGridLayout *groupLayout = new TQGridLayout( group->layout(), 2, 2,
KDialog::spacingHint() );
- mBox = new QListBox( group );
- connect( mBox, SIGNAL( selectionChanged( QListBoxItem* ) ),
- SLOT( selectionChanged( QListBoxItem* ) ) );
+ mBox = new TQListBox( group );
+ connect( mBox, TQT_SIGNAL( selectionChanged( TQListBoxItem* ) ),
+ TQT_SLOT( selectionChanged( TQListBoxItem* ) ) );
groupLayout->addWidget( mBox, 0, 0 );
KButtonBox *bbox = new KButtonBox( group, Qt::Vertical );
- mAddButton = bbox->addButton( i18n( "Add..." ), this, SLOT( add() ) );
- mEditButton = bbox->addButton( i18n( "Edit..." ), this, SLOT( edit() ) );
+ mAddButton = bbox->addButton( i18n( "Add..." ), this, TQT_SLOT( add() ) );
+ mEditButton = bbox->addButton( i18n( "Edit..." ), this, TQT_SLOT( edit() ) );
mEditButton->setEnabled( false );
- mRemoveButton = bbox->addButton( i18n( "Remove" ), this, SLOT( remove() ) );
+ mRemoveButton = bbox->addButton( i18n( "Remove" ), this, TQT_SLOT( remove() ) );
mRemoveButton->setEnabled( false );
bbox->layout();
groupLayout->addWidget( bbox, 0, 1 );
@@ -71,15 +71,15 @@ NamePartWidget::~NamePartWidget()
{
}
-void NamePartWidget::setNameParts( const QStringList &list )
+void NamePartWidget::setNameParts( const TQStringList &list )
{
mBox->clear();
mBox->insertStringList( list );
}
-QStringList NamePartWidget::nameParts() const
+TQStringList NamePartWidget::nameParts() const
{
- QStringList parts;
+ TQStringList parts;
for ( uint i = 0; i < mBox->count(); ++i )
parts.append( mBox->text( i ) );
@@ -90,8 +90,8 @@ void NamePartWidget::add()
{
bool ok;
- QString namePart = KInputDialog::getText( i18n( "New" ), mLabel,
- QString::null, &ok );
+ TQString namePart = KInputDialog::getText( i18n( "New" ), mLabel,
+ TQString::null, &ok );
if ( ok && !namePart.isEmpty() ) {
mBox->insertItem( namePart );
emit modified();
@@ -106,7 +106,7 @@ void NamePartWidget::edit()
if ( index == -1 )
return;
- QString namePart = KInputDialog::getText( i18n( "Edit" ), mLabel,
+ TQString namePart = KInputDialog::getText( i18n( "Edit" ), mLabel,
mBox->text( index ), &ok );
if ( ok && !namePart.isEmpty() ) {
mBox->changeItem( namePart, index );
@@ -123,7 +123,7 @@ void NamePartWidget::remove()
emit modified();
}
-void NamePartWidget::selectionChanged( QListBoxItem *item )
+void NamePartWidget::selectionChanged( TQListBoxItem *item )
{
mEditButton->setEnabled( item != 0 );
mRemoveButton->setEnabled( item != 0 );
@@ -131,10 +131,10 @@ void NamePartWidget::selectionChanged( QListBoxItem *item )
-AddresseeWidget::AddresseeWidget( QWidget *parent, const char *name )
- : QWidget( parent, name )
+AddresseeWidget::AddresseeWidget( TQWidget *parent, const char *name )
+ : TQWidget( parent, name )
{
- QGridLayout *layout = new QGridLayout( this, 2, 3, KDialog::marginHint(),
+ TQGridLayout *layout = new TQGridLayout( this, 2, 3, KDialog::marginHint(),
KDialog::spacingHint() );
mPrefix = new NamePartWidget( i18n( "Prefixes"), i18n( "Enter prefix:" ), this );
@@ -146,7 +146,7 @@ AddresseeWidget::AddresseeWidget( QWidget *parent, const char *name )
mSuffix = new NamePartWidget( i18n( "Suffixes" ), i18n( "Enter suffix:" ), this );
layout->addWidget( mSuffix, 0, 2 );
- QLabel *label = new QLabel( i18n( "Default formatted name:" ), this );
+ TQLabel *label = new TQLabel( i18n( "Default formatted name:" ), this );
layout->addWidget( label, 1, 0 );
mFormattedNameCombo = new KComboBox( this );
@@ -157,10 +157,10 @@ AddresseeWidget::AddresseeWidget( QWidget *parent, const char *name )
mFormattedNameCombo->insertItem( i18n( "Reverse Name" ) );
layout->addMultiCellWidget( mFormattedNameCombo, 1, 1, 1, 2 );
- connect( mPrefix, SIGNAL( modified() ), SIGNAL( modified() ) );
- connect( mInclusion, SIGNAL( modified() ), SIGNAL( modified() ) );
- connect( mSuffix, SIGNAL( modified() ), SIGNAL( modified() ) );
- connect( mFormattedNameCombo, SIGNAL( activated( int ) ), SIGNAL( modified() ) );
+ connect( mPrefix, TQT_SIGNAL( modified() ), TQT_SIGNAL( modified() ) );
+ connect( mInclusion, TQT_SIGNAL( modified() ), TQT_SIGNAL( modified() ) );
+ connect( mSuffix, TQT_SIGNAL( modified() ), TQT_SIGNAL( modified() ) );
+ connect( mFormattedNameCombo, TQT_SIGNAL( activated( int ) ), TQT_SIGNAL( modified() ) );
}
AddresseeWidget::~AddresseeWidget()
@@ -196,7 +196,7 @@ void AddresseeWidget::saveSettings()
DCOPClient *client = DCOPClient::mainClient();
if ( client )
- client->emitDCOPSignal( "KABC::AddressBookConfig", "changed()", QByteArray() );
+ client->emitDCOPSignal( "KABC::AddressBookConfig", "changed()", TQByteArray() );
}
#include "addresseewidget.moc"
diff --git a/kaddressbook/kcmconfigs/addresseewidget.h b/kaddressbook/kcmconfigs/addresseewidget.h
index c942ee42..9f4b4332 100644
--- a/kaddressbook/kcmconfigs/addresseewidget.h
+++ b/kaddressbook/kcmconfigs/addresseewidget.h
@@ -24,7 +24,7 @@
#ifndef ADDRESSEEWIDGET_H
#define ADDRESSEEWIDGET_H
-#include <qwidget.h>
+#include <tqwidget.h>
class KComboBox;
class KLineEdit;
@@ -38,12 +38,12 @@ class NamePartWidget : public QWidget
Q_OBJECT
public:
- NamePartWidget( const QString &title, const QString &label, QWidget *parent,
+ NamePartWidget( const TQString &title, const TQString &label, TQWidget *parent,
const char *name = 0 );
~NamePartWidget();
- void setNameParts( const QStringList &list );
- QStringList nameParts() const;
+ void setNameParts( const TQStringList &list );
+ TQStringList nameParts() const;
signals:
void modified();
@@ -53,16 +53,16 @@ class NamePartWidget : public QWidget
void edit();
void remove();
- void selectionChanged( QListBoxItem* );
+ void selectionChanged( TQListBoxItem* );
private:
- QListBox *mBox;
- QPushButton *mAddButton;
- QPushButton *mEditButton;
- QPushButton *mRemoveButton;
+ TQListBox *mBox;
+ TQPushButton *mAddButton;
+ TQPushButton *mEditButton;
+ TQPushButton *mRemoveButton;
- QString mTitle;
- QString mLabel;
+ TQString mTitle;
+ TQString mLabel;
};
class AddresseeWidget : public QWidget
@@ -70,7 +70,7 @@ class AddresseeWidget : public QWidget
Q_OBJECT
public:
- AddresseeWidget( QWidget *parent, const char *name = 0 );
+ AddresseeWidget( TQWidget *parent, const char *name = 0 );
~AddresseeWidget();
void restoreSettings();
diff --git a/kaddressbook/kcmconfigs/extensionconfigdialog.cpp b/kaddressbook/kcmconfigs/extensionconfigdialog.cpp
index 70a8d1af..80f73f46 100644
--- a/kaddressbook/kcmconfigs/extensionconfigdialog.cpp
+++ b/kaddressbook/kcmconfigs/extensionconfigdialog.cpp
@@ -21,7 +21,7 @@
without including the source code for Qt in the source distribution.
*/
-#include <qlayout.h>
+#include <tqlayout.h>
#include <klocale.h>
@@ -30,12 +30,12 @@
#include "extensionwidget.h"
ExtensionConfigDialog::ExtensionConfigDialog( KAB::ExtensionFactory *factory, KConfig *config,
- QWidget *parent, const char *name )
+ TQWidget *parent, const char *name )
: KDialogBase( Plain, i18n( "Extension Settings" ), Ok | Cancel, Ok, parent,
name, true, true ), mWidget( 0 ), mConfig( config )
{
- QFrame *page = plainPage();
- QGridLayout *layout = new QGridLayout( page, 1, 1, marginHint(), spacingHint() );
+ TQFrame *page = plainPage();
+ TQGridLayout *layout = new TQGridLayout( page, 1, 1, marginHint(), spacingHint() );
mWidget = factory->configureWidget( page, "ExtensionConfigWidget" );
layout->addWidget( mWidget, 0, 0 );
diff --git a/kaddressbook/kcmconfigs/extensionconfigdialog.h b/kaddressbook/kcmconfigs/extensionconfigdialog.h
index 1547647a..34339fa0 100644
--- a/kaddressbook/kcmconfigs/extensionconfigdialog.h
+++ b/kaddressbook/kcmconfigs/extensionconfigdialog.h
@@ -38,7 +38,7 @@ class ExtensionConfigDialog : public KDialogBase
public:
ExtensionConfigDialog( KAB::ExtensionFactory *factory, KConfig *config,
- QWidget *parent, const char *name = 0 );
+ TQWidget *parent, const char *name = 0 );
~ExtensionConfigDialog();
protected slots:
diff --git a/kaddressbook/kcmconfigs/kabconfigwidget.cpp b/kaddressbook/kcmconfigs/kabconfigwidget.cpp
index 7c57a926..e4fea740 100644
--- a/kaddressbook/kcmconfigs/kabconfigwidget.cpp
+++ b/kaddressbook/kcmconfigs/kabconfigwidget.cpp
@@ -21,16 +21,16 @@
without including the source code for Qt in the source distribution.
*/
-#include <qcheckbox.h>
-#include <qframe.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qtabwidget.h>
-#include <qtooltip.h>
-#include <qcombobox.h>
+#include <tqcheckbox.h>
+#include <tqframe.h>
+#include <tqgroupbox.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqpushbutton.h>
+#include <tqtabwidget.h>
+#include <tqtooltip.h>
+#include <tqcombobox.h>
#include <kconfig.h>
#include <kdebug.h>
@@ -45,31 +45,31 @@
#include "kabconfigwidget.h"
-KABConfigWidget::KABConfigWidget( QWidget *parent, const char *name )
- : QWidget( parent, name )
+KABConfigWidget::KABConfigWidget( TQWidget *parent, const char *name )
+ : TQWidget( parent, name )
{
- QVBoxLayout *topLayout = new QVBoxLayout( this, 0,
+ TQVBoxLayout *topLayout = new TQVBoxLayout( this, 0,
KDialog::spacingHint() );
- QTabWidget *tabWidget = new QTabWidget( this );
+ TQTabWidget *tabWidget = new TQTabWidget( this );
topLayout->addWidget( tabWidget );
// General page
- QWidget *generalPage = new QWidget( this );
- QVBoxLayout *layout = new QVBoxLayout( generalPage, KDialog::marginHint(),
+ TQWidget *generalPage = new TQWidget( this );
+ TQVBoxLayout *layout = new TQVBoxLayout( generalPage, KDialog::marginHint(),
KDialog::spacingHint() );
- QGroupBox *groupBox = new QGroupBox( 0, Qt::Vertical, i18n( "General" ), generalPage );
- QBoxLayout *boxLayout = new QVBoxLayout( groupBox->layout() );
+ TQGroupBox *groupBox = new TQGroupBox( 0, Qt::Vertical, i18n( "General" ), generalPage );
+ TQBoxLayout *boxLayout = new TQVBoxLayout( groupBox->layout() );
boxLayout->setAlignment( Qt::AlignTop );
- mViewsSingleClickBox = new QCheckBox( i18n( "Honor KDE single click" ), groupBox, "msingle" );
+ mViewsSingleClickBox = new TQCheckBox( i18n( "Honor KDE single click" ), groupBox, "msingle" );
boxLayout->addWidget( mViewsSingleClickBox );
- mNameParsing = new QCheckBox( i18n( "Automatic name parsing for new addressees" ), groupBox, "mparse" );
+ mNameParsing = new TQCheckBox( i18n( "Automatic name parsing for new addressees" ), groupBox, "mparse" );
boxLayout->addWidget( mNameParsing );
- mTradeAsFamilyName = new QCheckBox( i18n( "Trade single name component as family name" ), groupBox, "mtrade" );
+ mTradeAsFamilyName = new TQCheckBox( i18n( "Trade single name component as family name" ), groupBox, "mtrade" );
boxLayout->addWidget( mTradeAsFamilyName );
/**
TODO: show the checkbox when we can compile agains kdelibs from HEAD, atm it
@@ -77,15 +77,15 @@ KABConfigWidget::KABConfigWidget( QWidget *parent, const char *name )
*/
mTradeAsFamilyName->hide();
- mLimitContactDisplay = new QCheckBox( i18n( "Limit unfiltered display to 100 contacts" ), groupBox, "mlimit" );
+ mLimitContactDisplay = new TQCheckBox( i18n( "Limit unfiltered display to 100 contacts" ), groupBox, "mlimit" );
boxLayout->addWidget( mLimitContactDisplay );
- QBoxLayout *editorLayout = new QHBoxLayout( boxLayout, KDialog::spacingHint() );
+ TQBoxLayout *editorLayout = new TQHBoxLayout( boxLayout, KDialog::spacingHint() );
- QLabel *label = new QLabel( i18n( "Addressee editor type:" ), groupBox );
+ TQLabel *label = new TQLabel( i18n( "Addressee editor type:" ), groupBox );
editorLayout->addWidget( label );
- mEditorCombo = new QComboBox( groupBox );
+ mEditorCombo = new TQComboBox( groupBox );
mEditorCombo->insertItem( i18n( "Full Editor" ) );
mEditorCombo->insertItem( i18n( "Simple Editor" ) );
label->setBuddy( mEditorCombo );
@@ -96,29 +96,29 @@ KABConfigWidget::KABConfigWidget( QWidget *parent, const char *name )
layout->addWidget( groupBox );
- groupBox = new QGroupBox( 0, Qt::Vertical, i18n( "Script-Hooks" ), generalPage );
- QGridLayout *grid = new QGridLayout( groupBox->layout(), 3, 2,
+ groupBox = new TQGroupBox( 0, Qt::Vertical, i18n( "Script-Hooks" ), generalPage );
+ TQGridLayout *grid = new TQGridLayout( groupBox->layout(), 3, 2,
KDialog::spacingHint() );
- label = new QLabel( i18n( "Phone:" ), groupBox );
+ label = new TQLabel( i18n( "Phone:" ), groupBox );
grid->addWidget( label, 0, 0 );
- mPhoneHook = new QLineEdit( groupBox );
- QToolTip::add( mPhoneHook, i18n( "<ul><li>%N: Phone Number</li></ul>" ) );
+ mPhoneHook = new TQLineEdit( groupBox );
+ TQToolTip::add( mPhoneHook, i18n( "<ul><li>%N: Phone Number</li></ul>" ) );
grid->addWidget( mPhoneHook, 0, 1 );
- label = new QLabel( i18n( "Fax:" ), groupBox );
+ label = new TQLabel( i18n( "Fax:" ), groupBox );
grid->addWidget( label, 1, 0 );
- mFaxHook = new QLineEdit( groupBox );
- QToolTip::add( mFaxHook, i18n( "<ul><li>%N: Fax Number</li></ul>" ) );
+ mFaxHook = new TQLineEdit( groupBox );
+ TQToolTip::add( mFaxHook, i18n( "<ul><li>%N: Fax Number</li></ul>" ) );
grid->addWidget( mFaxHook, 1, 1 );
- label = new QLabel( i18n( "SMS Text:" ), groupBox );
+ label = new TQLabel( i18n( "SMS Text:" ), groupBox );
grid->addWidget( label, 2, 0 );
- mSMSHook = new QLineEdit( groupBox );
- QToolTip::add( mSMSHook, i18n( "<ul><li>%N: Phone Number</li><li>%F: File containing the text message(s)</li></ul>" ) );
+ mSMSHook = new TQLineEdit( groupBox );
+ TQToolTip::add( mSMSHook, i18n( "<ul><li>%N: Phone Number</li><li>%F: File containing the text message(s)</li></ul>" ) );
grid->addWidget( mSMSHook, 2, 1 );
@@ -126,13 +126,13 @@ KABConfigWidget::KABConfigWidget( QWidget *parent, const char *name )
layout->addWidget( groupBox );
- groupBox = new QGroupBox( 0, Qt::Vertical, i18n( "Location Map" ), generalPage );
- boxLayout = new QVBoxLayout( groupBox->layout(), KDialog::spacingHint() );
+ groupBox = new TQGroupBox( 0, Qt::Vertical, i18n( "Location Map" ), generalPage );
+ boxLayout = new TQVBoxLayout( groupBox->layout(), KDialog::spacingHint() );
boxLayout->setAlignment( Qt::AlignTop );
- mLocationMapURL = new QComboBox( true, groupBox );
- mLocationMapURL->setSizePolicy( QSizePolicy( QSizePolicy::Preferred, QSizePolicy::Fixed ) );
- QToolTip::add( mLocationMapURL, i18n( "<ul> <li>%s: Street</li>"
+ mLocationMapURL = new TQComboBox( true, groupBox );
+ mLocationMapURL->setSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed ) );
+ TQToolTip::add( mLocationMapURL, i18n( "<ul> <li>%s: Street</li>"
"<li>%r: Region</li>"
"<li>%l: Location</li>"
"<li>%z: Zip Code</li>"
@@ -141,22 +141,22 @@ KABConfigWidget::KABConfigWidget( QWidget *parent, const char *name )
boxLayout->addWidget( mLocationMapURL );
layout->addWidget( groupBox );
- connect( mNameParsing, SIGNAL( toggled( bool ) ), SLOT( modified() ) );
- connect( mViewsSingleClickBox, SIGNAL( toggled( bool ) ), SLOT( modified() ) );
- connect( mTradeAsFamilyName, SIGNAL( toggled( bool ) ), SLOT( modified() ) );
- connect( mLimitContactDisplay, SIGNAL( toggled( bool ) ), SLOT( modified() ) );
- connect( mPhoneHook, SIGNAL( textChanged( const QString& ) ), SLOT( modified() ) );
- connect( mSMSHook, SIGNAL( textChanged( const QString& ) ), SLOT( modified() ) );
- connect( mFaxHook, SIGNAL( textChanged( const QString& ) ), SLOT( modified() ) );
- connect( mLocationMapURL, SIGNAL( textChanged( const QString& ) ), SLOT( modified() ) );
- connect( mEditorCombo, SIGNAL( activated( int ) ), SLOT( modified() ) );
+ connect( mNameParsing, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( modified() ) );
+ connect( mViewsSingleClickBox, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( modified() ) );
+ connect( mTradeAsFamilyName, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( modified() ) );
+ connect( mLimitContactDisplay, TQT_SIGNAL( toggled( bool ) ), TQT_SLOT( modified() ) );
+ connect( mPhoneHook, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( modified() ) );
+ connect( mSMSHook, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( modified() ) );
+ connect( mFaxHook, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( modified() ) );
+ connect( mLocationMapURL, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( modified() ) );
+ connect( mEditorCombo, TQT_SIGNAL( activated( int ) ), TQT_SLOT( modified() ) );
tabWidget->addTab( generalPage, i18n( "General" ) );
// Addressee page
mAddresseeWidget = new AddresseeWidget( this );
tabWidget->addTab( mAddresseeWidget, i18n( "Contact" ) );
- connect( mAddresseeWidget, SIGNAL( modified() ), SLOT( modified() ) );
+ connect( mAddresseeWidget, TQT_SIGNAL( modified() ), TQT_SLOT( modified() ) );
}
void KABConfigWidget::restoreSettings()
diff --git a/kaddressbook/kcmconfigs/kabconfigwidget.h b/kaddressbook/kcmconfigs/kabconfigwidget.h
index 72b3e88f..3e571869 100644
--- a/kaddressbook/kcmconfigs/kabconfigwidget.h
+++ b/kaddressbook/kcmconfigs/kabconfigwidget.h
@@ -24,7 +24,7 @@
#ifndef KABCONFIGWIDGET_H
#define KABCONFIGWIDGET_H
-#include <qwidget.h>
+#include <tqwidget.h>
class QCheckBox;
class QLineEdit;
@@ -41,7 +41,7 @@ class KABConfigWidget : public QWidget
Q_OBJECT
public:
- KABConfigWidget( QWidget *parent, const char *name = 0 );
+ KABConfigWidget( TQWidget *parent, const char *name = 0 );
void restoreSettings();
void saveSettings();
@@ -54,15 +54,15 @@ class KABConfigWidget : public QWidget
void modified();
private:
- QCheckBox *mNameParsing;
- QCheckBox *mViewsSingleClickBox;
- QCheckBox *mTradeAsFamilyName;
- QComboBox *mEditorCombo;
- QLineEdit *mPhoneHook;
- QLineEdit *mFaxHook;
- QLineEdit *mSMSHook;
- QCheckBox *mLimitContactDisplay;
- QComboBox *mLocationMapURL;
+ TQCheckBox *mNameParsing;
+ TQCheckBox *mViewsSingleClickBox;
+ TQCheckBox *mTradeAsFamilyName;
+ TQComboBox *mEditorCombo;
+ TQLineEdit *mPhoneHook;
+ TQLineEdit *mFaxHook;
+ TQLineEdit *mSMSHook;
+ TQCheckBox *mLimitContactDisplay;
+ TQComboBox *mLocationMapURL;
AddresseeWidget *mAddresseeWidget;
};
diff --git a/kaddressbook/kcmconfigs/kcmkabconfig.cpp b/kaddressbook/kcmconfigs/kcmkabconfig.cpp
index 97fee466..6b516249 100644
--- a/kaddressbook/kcmconfigs/kcmkabconfig.cpp
+++ b/kaddressbook/kcmconfigs/kcmkabconfig.cpp
@@ -21,7 +21,7 @@
without including the source code for Qt in the source distribution.
*/
-#include <qlayout.h>
+#include <tqlayout.h>
#include <kaboutdata.h>
#include <kdebug.h>
@@ -35,19 +35,19 @@
extern "C"
{
- KDE_EXPORT KCModule *create_kabconfig( QWidget *parent, const char * ) {
+ KDE_EXPORT KCModule *create_kabconfig( TQWidget *parent, const char * ) {
return new KCMKabConfig( parent, "kcmkabconfig" );
}
}
-KCMKabConfig::KCMKabConfig( QWidget *parent, const char *name )
+KCMKabConfig::KCMKabConfig( TQWidget *parent, const char *name )
: KCModule( parent, name )
{
- QVBoxLayout *layout = new QVBoxLayout( this );
+ TQVBoxLayout *layout = new TQVBoxLayout( this );
mConfigWidget = new KABConfigWidget( this, "mConfigWidget" );
layout->addWidget( mConfigWidget );
- connect( mConfigWidget, SIGNAL( changed( bool ) ), SIGNAL( changed( bool ) ) );
+ connect( mConfigWidget, TQT_SIGNAL( changed( bool ) ), TQT_SIGNAL( changed( bool ) ) );
load();
diff --git a/kaddressbook/kcmconfigs/kcmkabconfig.h b/kaddressbook/kcmconfigs/kcmkabconfig.h
index a42dff08..5ffecea5 100644
--- a/kaddressbook/kcmconfigs/kcmkabconfig.h
+++ b/kaddressbook/kcmconfigs/kcmkabconfig.h
@@ -33,7 +33,7 @@ class KCMKabConfig : public KCModule
Q_OBJECT
public:
- KCMKabConfig( QWidget *parent = 0, const char *name = 0 );
+ KCMKabConfig( TQWidget *parent = 0, const char *name = 0 );
virtual void load();
virtual void save();
diff --git a/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp b/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp
index 0c70b08b..3b127eab 100644
--- a/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp
+++ b/kaddressbook/kcmconfigs/kcmkabcustomfields.cpp
@@ -27,51 +27,51 @@
#include <kstandarddirs.h>
-#include <qregexp.h>
+#include <tqregexp.h>
#include <kdepimmacros.h>
extern "C"
{
- KDE_EXPORT KCModule *create_kabcustomfields( QWidget *parent, const char * ) {
+ KDE_EXPORT KCModule *create_kabcustomfields( TQWidget *parent, const char * ) {
return new KCMKabCustomFields( parent, "kcmkabcustomfields" );
}
}
-KCMKabCustomFields::KCMKabCustomFields( QWidget *parent, const char *name )
+KCMKabCustomFields::KCMKabCustomFields( TQWidget *parent, const char *name )
: KCMDesignerFields( parent, name )
{
}
-QString KCMKabCustomFields::localUiDir()
+TQString KCMKabCustomFields::localUiDir()
{
return kabLocalDir() + "contacteditorpages/";
}
-QString KCMKabCustomFields::uiPath()
+TQString KCMKabCustomFields::uiPath()
{
return "kaddressbook/contacteditorpages/";
}
-void KCMKabCustomFields::writeActivePages( const QStringList &activePages )
+void KCMKabCustomFields::writeActivePages( const TQStringList &activePages )
{
KABPrefs::instance()->setAdvancedCustomFields( activePages );
KABPrefs::instance()->writeConfig();
}
-QStringList KCMKabCustomFields::readActivePages()
+TQStringList KCMKabCustomFields::readActivePages()
{
return KABPrefs::instance()->advancedCustomFields();
}
-QString KCMKabCustomFields::applicationName()
+TQString KCMKabCustomFields::applicationName()
{
return "KADDRESSBOOK";
}
-QString KCMKabCustomFields::kabLocalDir()
+TQString KCMKabCustomFields::kabLocalDir()
{
- QStringList kabdirs = locateLocal("data", "kaddressbook/");
- return kabdirs.grep( QRegExp( "^"+KGlobal::dirs()->localkdedir() ) ).first();
+ TQStringList kabdirs = locateLocal("data", "kaddressbook/");
+ return kabdirs.grep( TQRegExp( "^"+KGlobal::dirs()->localkdedir() ) ).first();
}
diff --git a/kaddressbook/kcmconfigs/kcmkabcustomfields.h b/kaddressbook/kcmconfigs/kcmkabcustomfields.h
index 1501c42e..38cd19a9 100644
--- a/kaddressbook/kcmconfigs/kcmkabcustomfields.h
+++ b/kaddressbook/kcmconfigs/kcmkabcustomfields.h
@@ -28,16 +28,16 @@
class KCMKabCustomFields : public KPIM::KCMDesignerFields
{
public:
- KCMKabCustomFields( QWidget *parent = 0, const char *name = 0 );
+ KCMKabCustomFields( TQWidget *parent = 0, const char *name = 0 );
protected:
- QString localUiDir();
- QString uiPath();
- void writeActivePages( const QStringList & );
- QStringList readActivePages();
- QString applicationName();
+ TQString localUiDir();
+ TQString uiPath();
+ void writeActivePages( const TQStringList & );
+ TQStringList readActivePages();
+ TQString applicationName();
- QString kabLocalDir();
+ TQString kabLocalDir();
};
#endif
diff --git a/kaddressbook/kcmconfigs/kcmkabldapconfig.cpp b/kaddressbook/kcmconfigs/kcmkabldapconfig.cpp
index 48c83a54..e899198b 100644
--- a/kaddressbook/kcmconfigs/kcmkabldapconfig.cpp
+++ b/kaddressbook/kcmconfigs/kcmkabldapconfig.cpp
@@ -21,9 +21,9 @@
without including the source code for Qt in the source distribution.
*/
-#include <qcheckbox.h>
-#include <qframe.h>
-#include <qlayout.h>
+#include <tqcheckbox.h>
+#include <tqframe.h>
+#include <tqlayout.h>
#include <kaboutdata.h>
#include <klocale.h>
@@ -36,19 +36,19 @@
extern "C"
{
- KDE_EXPORT KCModule *create_kabldapconfig( QWidget *parent, const char * ) {
+ KDE_EXPORT KCModule *create_kabldapconfig( TQWidget *parent, const char * ) {
return new KCMKabLdapConfig( parent, "kcmkabldapconfig" );
}
}
-KCMKabLdapConfig::KCMKabLdapConfig( QWidget *parent, const char *name )
+KCMKabLdapConfig::KCMKabLdapConfig( TQWidget *parent, const char *name )
: KCModule( parent, name )
{
- QVBoxLayout *layout = new QVBoxLayout( this );
+ TQVBoxLayout *layout = new TQVBoxLayout( this );
mConfigWidget = new LDAPOptionsWidget( this );
layout->addWidget( mConfigWidget );
- connect( mConfigWidget, SIGNAL( changed( bool ) ), SIGNAL( changed( bool ) ) );
+ connect( mConfigWidget, TQT_SIGNAL( changed( bool ) ), TQT_SIGNAL( changed( bool ) ) );
load();
diff --git a/kaddressbook/kcmconfigs/kcmkabldapconfig.h b/kaddressbook/kcmconfigs/kcmkabldapconfig.h
index 85e67053..53d1a21b 100644
--- a/kaddressbook/kcmconfigs/kcmkabldapconfig.h
+++ b/kaddressbook/kcmconfigs/kcmkabldapconfig.h
@@ -26,7 +26,7 @@
#include <kcmodule.h>
-#include <qwidget.h>
+#include <tqwidget.h>
class LDAPOptionsWidget;
@@ -35,7 +35,7 @@ class KCMKabLdapConfig : public KCModule
Q_OBJECT
public:
- KCMKabLdapConfig( QWidget *parent = 0, const char *name = 0 );
+ KCMKabLdapConfig( TQWidget *parent = 0, const char *name = 0 );
virtual void load();
virtual void save();
diff --git a/kaddressbook/kcmconfigs/ldapoptionswidget.h b/kaddressbook/kcmconfigs/ldapoptionswidget.h
index c63b96dd..22b7e621 100644
--- a/kaddressbook/kcmconfigs/ldapoptionswidget.h
+++ b/kaddressbook/kcmconfigs/ldapoptionswidget.h
@@ -24,7 +24,7 @@
#ifndef LDAPOPTIONSWIDGET_H
#define LDAPOPTIONSWIDGET_H
-#include <qwidget.h>
+#include <tqwidget.h>
class QToolButton;
class KListView;
@@ -36,7 +36,7 @@ class LDAPOptionsWidget : public QWidget
Q_OBJECT
public:
- LDAPOptionsWidget( QWidget* parent = 0, const char* name = 0 );
+ LDAPOptionsWidget( TQWidget* parent = 0, const char* name = 0 );
~LDAPOptionsWidget();
void restoreSettings();
@@ -50,8 +50,8 @@ class LDAPOptionsWidget : public QWidget
void slotAddHost();
void slotEditHost();
void slotRemoveHost();
- void slotSelectionChanged( QListViewItem* );
- void slotItemClicked( QListViewItem* );
+ void slotSelectionChanged( TQListViewItem* );
+ void slotItemClicked( TQListViewItem* );
void slotMoveUp();
void slotMoveDown();
@@ -60,12 +60,12 @@ class LDAPOptionsWidget : public QWidget
KListView* mHostListView;
- QPushButton* mAddButton;
- QPushButton* mEditButton;
- QPushButton* mRemoveButton;
+ TQPushButton* mAddButton;
+ TQPushButton* mEditButton;
+ TQPushButton* mRemoveButton;
- QToolButton* mUpButton;
- QToolButton* mDownButton;
+ TQToolButton* mUpButton;
+ TQToolButton* mDownButton;
};
#endif
diff --git a/kaddressbook/kcmconfigs/ldapoptionswidget.cpp b/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
index df80ad87..3825ac1d 100644
--- a/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
+++ b/kaddressbook/kcmconfigs/ldapoptionswidget.cpp
@@ -21,13 +21,13 @@
without including the source code for Qt in the source distribution.
*/
-#include <qgroupbox.h>
-#include <qheader.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qtoolbutton.h>
-#include <qstring.h>
+#include <tqgroupbox.h>
+#include <tqheader.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
+#include <tqtoolbutton.h>
+#include <tqstring.h>
#include <kapplication.h>
#include <kbuttonbox.h>
@@ -37,16 +37,16 @@
#include "addhostdialog.h"
#include "ldapoptionswidget.h"
-#include <qvgroupbox.h>
-#include <qhbox.h>
-#include <qvbox.h>
+#include <tqvgroupbox.h>
+#include <tqhbox.h>
+#include <tqvbox.h>
#include <kiconloader.h>
class LDAPItem : public QCheckListItem
{
public:
- LDAPItem( QListView *parent, const KPIM::LdapServer &server, bool isActive = false )
- : QCheckListItem( parent, parent->lastItem(), QString::null, QCheckListItem::CheckBox ),
+ LDAPItem( TQListView *parent, const KPIM::LdapServer &server, bool isActive = false )
+ : TQCheckListItem( parent, parent->lastItem(), TQString::null, TQCheckListItem::CheckBox ),
mIsActive( isActive )
{
setServer( server );
@@ -69,32 +69,32 @@ class LDAPItem : public QCheckListItem
bool mIsActive;
};
-LDAPOptionsWidget::LDAPOptionsWidget( QWidget* parent, const char* name )
- : QWidget( parent, name )
+LDAPOptionsWidget::LDAPOptionsWidget( TQWidget* parent, const char* name )
+ : TQWidget( parent, name )
{
initGUI();
mHostListView->setSorting( -1 );
mHostListView->setAllColumnsShowFocus( true );
mHostListView->setFullWidth( true );
- mHostListView->addColumn( QString::null );
+ mHostListView->addColumn( TQString::null );
mHostListView->header()->hide();
- connect( mHostListView, SIGNAL( selectionChanged( QListViewItem* ) ),
- SLOT( slotSelectionChanged( QListViewItem* ) ) );
- connect( mHostListView, SIGNAL(doubleClicked( QListViewItem *, const QPoint &, int )), this, SLOT(slotEditHost()));
- connect( mHostListView, SIGNAL( clicked( QListViewItem* ) ),
- SLOT( slotItemClicked( QListViewItem* ) ) );
+ connect( mHostListView, TQT_SIGNAL( selectionChanged( TQListViewItem* ) ),
+ TQT_SLOT( slotSelectionChanged( TQListViewItem* ) ) );
+ connect( mHostListView, TQT_SIGNAL(doubleClicked( TQListViewItem *, const TQPoint &, int )), this, TQT_SLOT(slotEditHost()));
+ connect( mHostListView, TQT_SIGNAL( clicked( TQListViewItem* ) ),
+ TQT_SLOT( slotItemClicked( TQListViewItem* ) ) );
- connect( mUpButton, SIGNAL( clicked() ), this, SLOT( slotMoveUp() ) );
- connect( mDownButton, SIGNAL( clicked() ), this, SLOT( slotMoveDown() ) );
+ connect( mUpButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveUp() ) );
+ connect( mDownButton, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotMoveDown() ) );
}
LDAPOptionsWidget::~LDAPOptionsWidget()
{
}
-void LDAPOptionsWidget::slotSelectionChanged( QListViewItem *item )
+void LDAPOptionsWidget::slotSelectionChanged( TQListViewItem *item )
{
bool state = ( item != 0 );
mEditButton->setEnabled( state );
@@ -103,7 +103,7 @@ void LDAPOptionsWidget::slotSelectionChanged( QListViewItem *item )
mUpButton->setEnabled( item && item->itemAbove() );
}
-void LDAPOptionsWidget::slotItemClicked( QListViewItem *item )
+void LDAPOptionsWidget::slotItemClicked( TQListViewItem *item )
{
LDAPItem *ldapItem = dynamic_cast<LDAPItem*>( item );
if ( !ldapItem )
@@ -146,7 +146,7 @@ void LDAPOptionsWidget::slotEditHost()
void LDAPOptionsWidget::slotRemoveHost()
{
- QListViewItem *item = mHostListView->currentItem();
+ TQListViewItem *item = mHostListView->currentItem();
if ( !item )
return;
@@ -200,7 +200,7 @@ void LDAPOptionsWidget::restoreSettings()
KConfig *config = KPIM::LdapSearch::config();
KConfigGroupSaver saver( config, "LDAP" );
- QString host;
+ TQString host;
uint count = config->readUnsignedNumEntry( "NumSelectedHosts");
for ( uint i = 0; i < count; ++i ) {
@@ -228,7 +228,7 @@ void LDAPOptionsWidget::saveSettings()
KConfigGroupSaver saver( config, "LDAP" );
uint selected = 0; uint unselected = 0;
- QListViewItemIterator it( mHostListView );
+ TQListViewItemIterator it( mHostListView );
for ( ; it.current(); ++it ) {
LDAPItem *item = dynamic_cast<LDAPItem*>( it.current() );
if ( !item )
@@ -258,46 +258,46 @@ void LDAPOptionsWidget::defaults()
void LDAPOptionsWidget::initGUI()
{
- QVBoxLayout *layout = new QVBoxLayout( this, 0, KDialog::spacingHint() );
+ TQVBoxLayout *layout = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
- QVGroupBox *groupBox = new QVGroupBox( i18n( "LDAP Servers" ), this );
+ TQVGroupBox *groupBox = new TQVGroupBox( i18n( "LDAP Servers" ), this );
groupBox->setInsideSpacing( KDialog::spacingHint() );
groupBox->setInsideMargin( KDialog::marginHint() );
- // Contents of the QVGroupBox: label and hbox
- /*QLabel *label =*/ new QLabel( i18n( "Check all servers that should be used:" ), groupBox );
+ // Contents of the TQVGroupBox: label and hbox
+ /*TQLabel *label =*/ new TQLabel( i18n( "Check all servers that should be used:" ), groupBox );
- QHBox* hBox = new QHBox( groupBox );
+ TQHBox* hBox = new TQHBox( groupBox );
hBox->setSpacing( 6 );
// Contents of the hbox: listview and up/down buttons on the right (vbox)
mHostListView = new KListView( hBox );
- QVBox* upDownBox = new QVBox( hBox );
+ TQVBox* upDownBox = new TQVBox( hBox );
upDownBox->setSpacing( 6 );
- mUpButton = new QToolButton( upDownBox, "mUpButton" );
+ mUpButton = new TQToolButton( upDownBox, "mUpButton" );
mUpButton->setIconSet( BarIconSet( "up", KIcon::SizeSmall ) );
mUpButton->setEnabled( false ); // b/c no item is selected yet
- mDownButton = new QToolButton( upDownBox, "mDownButton" );
+ mDownButton = new TQToolButton( upDownBox, "mDownButton" );
mDownButton->setIconSet( BarIconSet( "down", KIcon::SizeSmall ) );
mDownButton->setEnabled( false ); // b/c no item is selected yet
- QWidget* spacer = new QWidget( upDownBox );
+ TQWidget* spacer = new TQWidget( upDownBox );
upDownBox->setStretchFactor( spacer, 100 );
layout->addWidget( groupBox );
KButtonBox *buttons = new KButtonBox( this );
- buttons->addButton( i18n( "&Add Host..." ), this, SLOT( slotAddHost() ) );
- mEditButton = buttons->addButton( i18n( "&Edit Host..." ), this, SLOT( slotEditHost() ) );
+ buttons->addButton( i18n( "&Add Host..." ), this, TQT_SLOT( slotAddHost() ) );
+ mEditButton = buttons->addButton( i18n( "&Edit Host..." ), this, TQT_SLOT( slotEditHost() ) );
mEditButton->setEnabled( false );
- mRemoveButton = buttons->addButton( i18n( "&Remove Host" ), this, SLOT( slotRemoveHost() ) );
+ mRemoveButton = buttons->addButton( i18n( "&Remove Host" ), this, TQT_SLOT( slotRemoveHost() ) );
mRemoveButton->setEnabled( false );
buttons->layout();
layout->addWidget( buttons );
- resize( QSize( 460, 300 ).expandedTo( sizeHint() ) );
+ resize( TQSize( 460, 300 ).expandedTo( sizeHint() ) );
}
#include "ldapoptionswidget.moc"